pub enum SensitiveMatcher {
Exists,
Equals(Value),
Regex(String),
Gt(f64),
Lt(f64),
}Expand description
Matcher for a sensitive invocation predicate.
Variants
Exists
The selected value exists.
Equals(Value)
The selected value equals this JSON value.
Regex(String)
The selected string matches this regular expression.
Gt(f64)
The selected numeric value is greater than this threshold.
Lt(f64)
The selected numeric value is less than this threshold.